@@ -15,7 +15,7 @@ func getCmdStats(gs *state.GlobalState) *cobra.Command {
 		Long: `Show test metrics.
 
   Use the global --address flag to specify the URL to the API server.`,
-		RunE: func(cmd *cobra.Command, args []string) error {
+		RunE: func(_ *cobra.Command, _ []string) error {
 			c, err := client.New(gs.Flags.Address)
 			if err != nil {
 				return err
