@@ -6,14 +6,14 @@ import (
 	"fmt"
 	"math/rand"
 
-	"github.com/dop251/goja"
+	"github.com/grafana/sobek"
 )
 
 // NewRandSource is copied from goja's source code:
 // https://github.com/dop251/goja/blob/master/goja/main.go#L44
 // The returned RandSource is NOT safe for concurrent use:
 // https://golang.org/pkg/math/rand/#NewSource
-func NewRandSource() goja.RandSource {
+func NewRandSource() sobek.RandSource {
 	var seed int64
 	if err := binary.Read(crand.Reader, binary.LittleEndian, &seed); err != nil {
 		panic(fmt.Errorf("could not read random bytes: %w", err))
