@@ -84,7 +84,7 @@ var (
 	wrapOpts         = []templateArg{"soft", "hard", "off"}
 	kindOpts         = []templateArg{"subtitle", "captions", "descriptions", "chapters", "metadata"}
 
-	// These are the values allowed for the crossorigin attribute, used by the nullableEnumTemplates is always goja.Undefined
+	// These are the values allowed for the crossorigin attribute, used by the nullableEnumTemplates is always sobek.Undefined
 	crossOriginOpts = []templateArg{"anonymous", "use-credentials"}
 )
 
@@ -104,8 +104,8 @@ var (
 //	enumTemplate: uses any number or more TemplateArg, the gen'd func always returns one of the values in
 //	              the TemplateArgs. The first item in the list is used as the default when the attribute
 //	              was invalid or unset.
-//	nullableEnumTemplate: similar to the enumTemplate except the default is goja.Undefined and the
-//	                      return type is goja.Value
+//	nullableEnumTemplate: similar to the enumTemplate except the default is sobek.Undefined and the
+//	                      return type is sobek.Value
 //
 //nolint:gochecknoglobals
 var funcDefs = []struct {
@@ -371,11 +371,11 @@ var elemFuncsTemplate = template.Must(template.New("").Funcs(template.FuncMap{
 }).Parse(`// generated by js/modules/k6/html/gen/gen_elements.go;  DO NOT EDIT
 package html
 
-import "github.com/dop251/goja"
+import "github.com/grafana/sobek"
 
-func selToElement(sel Selection) goja.Value {
+func selToElement(sel Selection) sobek.Value {
 	if sel.sel.Length() == 0 {
-		return goja.Undefined()
+		return sobek.Undefined()
 	}
 
 	elem := Element{sel.sel.Nodes[0], &sel}
@@ -411,7 +411,7 @@ func ({{ receiverName $funcDef.Elem }} {{$funcDef.Elem}}) {{$funcDef.Method}}()
 {{- else if eq $funcDef.TemplateType $templateTypes.GojaEnum }}
 	attrVal, exists := {{ receiverName $funcDef.Elem }}.sel.sel.Attr("{{ $funcDef.Attr }}")
 	if !exists {
-		return goja.Undefined()
+		return sobek.Undefined()
 	}
 	switch attrVal {
 	{{- range $optVal := $funcDef.TemplateArgs }}
@@ -419,7 +419,7 @@ func ({{ receiverName $funcDef.Elem }} {{$funcDef.Elem}}) {{$funcDef.Method}}()
 		return {{ receiverName $funcDef.Elem }}.sel.rt.ToValue(attrVal)
 	{{- end}}
 	default:
-		return goja.Undefined()
+		return sobek.Undefined()
 	}
 {{- else if eq $funcDef.TemplateType $templateTypes.Const }}
 	return "{{ index $funcDef.TemplateArgs 0 }}"
@@ -451,7 +451,7 @@ func returnType(tt templateType) string {
 	case intTemplate:
 		return "int"
 	case nullableEnumTemplate:
-		return "goja.Value"
+		return "sobek.Value"
 	default:
 		return "string"
 	}
