@@ -8,7 +8,7 @@ import (
 	"net/url"
 	"strings"
 
-	"github.com/dop251/goja"
+	"github.com/grafana/sobek"
 	"github.com/tidwall/gjson"
 
 	"go.k6.io/k6/js/common"
@@ -62,7 +62,7 @@ func (res *Response) HTML(selector ...string) html.Selection {
 }
 
 // JSON parses the body of a response as JSON and returns it to the goja VM.
-func (res *Response) JSON(selector ...string) goja.Value {
+func (res *Response) JSON(selector ...string) sobek.Value {
 	rt := res.client.moduleInstance.vu.Runtime()
 
 	if res.Body == nil {
@@ -83,7 +83,7 @@ func (res *Response) JSON(selector ...string) goja.Value {
 		if hasSelector {
 			if !res.validatedJSON {
 				if !gjson.ValidBytes(body) {
-					return goja.Undefined()
+					return sobek.Undefined()
 				}
 				res.validatedJSON = true
 			}
@@ -91,7 +91,7 @@ func (res *Response) JSON(selector ...string) goja.Value {
 			result := gjson.GetBytes(body, selector[0])
 
 			if !result.Exists() {
-				return goja.Undefined()
+				return sobek.Undefined()
 			}
 			return rt.ToValue(result.Value())
 		}
@@ -136,13 +136,13 @@ func checkErrorInJSON(input []byte, offset int, err error) error {
 // TODO: document the actual arguments that can be provided
 //
 //nolint:funlen
-func (res *Response) SubmitForm(args ...goja.Value) (*Response, error) {
+func (res *Response) SubmitForm(args ...sobek.Value) (*Response, error) {
 	rt := res.client.moduleInstance.vu.Runtime()
 
 	formSelector := "form"
 	submitSelector := "[type=\"submit\"]"
-	var fields map[string]goja.Value
-	requestParams := goja.Null()
+	var fields map[string]sobek.Value
+	requestParams := sobek.Null()
 	if len(args) > 0 {
 		params := args[0].ToObject(rt)
 		for _, k := range params.Keys() {
@@ -168,7 +168,7 @@ func (res *Response) SubmitForm(args ...goja.Value) (*Response, error) {
 
 	methodAttr := form.Attr("method")
 	var requestMethod string
-	if methodAttr == goja.Undefined() {
+	if methodAttr == sobek.Undefined() {
 		// Use GET by default
 		requestMethod = http.MethodGet
 	} else {
@@ -182,7 +182,7 @@ func (res *Response) SubmitForm(args ...goja.Value) (*Response, error) {
 
 	actionAttr := form.Attr("action")
 	var requestURL *url.URL
-	if actionAttr == goja.Undefined() {
+	if actionAttr == sobek.Undefined() {
 		// Use the url of the response if no action is set
 		requestURL = responseURL
 	} else {
@@ -200,7 +200,7 @@ func (res *Response) SubmitForm(args ...goja.Value) (*Response, error) {
 	submit := form.Find(submitSelector)
 	submitName := submit.Attr("name")
 	submitValue := submit.Val()
-	if submitName != goja.Undefined() && submitValue != goja.Undefined() {
+	if submitName != sobek.Undefined() && submitValue != sobek.Undefined() {
 		values[submitName.String()] = submitValue
 	}
 
@@ -215,7 +215,7 @@ func (res *Response) SubmitForm(args ...goja.Value) (*Response, error) {
 			q.Add(k, v.String())
 		}
 		requestURL.RawQuery = q.Encode()
-		return res.client.Request(requestMethod, rt.ToValue(requestURL.String()), goja.Null(), requestParams)
+		return res.client.Request(requestMethod, rt.ToValue(requestURL.String()), sobek.Null(), requestParams)
 	}
 	return res.client.Request(
 		requestMethod, rt.ToValue(requestURL.String()),
@@ -225,11 +225,11 @@ func (res *Response) SubmitForm(args ...goja.Value) (*Response, error) {
 
 // ClickLink parses the body as an html, looks for a link and than makes a request as if the link was
 // clicked
-func (res *Response) ClickLink(args ...goja.Value) (*Response, error) {
+func (res *Response) ClickLink(args ...sobek.Value) (*Response, error) {
 	rt := res.client.moduleInstance.vu.Runtime()
 
 	selector := "a[href]"
-	requestParams := goja.Null()
+	requestParams := sobek.Null()
 	if len(args) > 0 {
 		params := args[0].ToObject(rt)
 		for _, k := range params.Keys() {
@@ -252,7 +252,7 @@ func (res *Response) ClickLink(args ...goja.Value) (*Response, error) {
 		common.Throw(rt, fmt.Errorf("no element found for selector '%s' in response '%s'", selector, res.URL))
 	}
 	hrefAttr := link.Attr("href")
-	if hrefAttr == goja.Undefined() {
+	if hrefAttr == sobek.Undefined() {
 		errmsg := fmt.Errorf("no valid href attribute value found on element '%s' in response '%s'", selector, res.URL)
 		common.Throw(rt, errmsg)
 	}
@@ -262,5 +262,5 @@ func (res *Response) ClickLink(args ...goja.Value) (*Response, error) {
 	}
 	requestURL := responseURL.ResolveReference(hrefURL)
 
-	return res.client.Request(http.MethodGet, rt.ToValue(requestURL.String()), goja.Undefined(), requestParams)
+	return res.client.Request(http.MethodGet, rt.ToValue(requestURL.String()), sobek.Undefined(), requestParams)
 }
