@@ -2,7 +2,7 @@
 package promises
 
 import (
-	"github.com/dop251/goja"
+	"github.com/grafana/sobek"
 	"go.k6.io/k6/js/modules"
 )
 
@@ -14,7 +14,7 @@ import (
 //
 // A typical usage would be:
 //
-//	   func myAsynchronousFunc(vu modules.VU) *(goja.Promise) {
+//	   func myAsynchronousFunc(vu modules.VU) *(sobek.Promise) {
 //		    promise, resolve, reject := promises.New(vu)
 //		    go func() {
 //		        v, err := someAsyncFunc()
@@ -27,7 +27,7 @@ import (
 //		    }()
 //		    return promise
 //		  }
-func New(vu modules.VU) (p *goja.Promise, resolve func(result any), reject func(reason any)) {
+func New(vu modules.VU) (p *sobek.Promise, resolve func(result any), reject func(reason any)) {
 	p, resolveFunc, rejectFunc := vu.Runtime().NewPromise()
 	callback := vu.RegisterCallback()
 
