@@ -89,24 +89,6 @@ func TestRunnerNew(t *testing.T) {
 	})
 }
 
-func TestRunnerGetDefaultGroup(t *testing.T) {
-	t.Parallel()
-	r1, err := getSimpleRunner(t, "/script.js", `exports.default = function() {};`)
-	require.NoError(t, err)
-	assert.NotNil(t, r1.GetDefaultGroup())
-
-	registry := metrics.NewRegistry()
-	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
-	r2, err := NewFromArchive(
-		&lib.TestPreInitState{
-			Logger:         testutils.NewLogger(t),
-			BuiltinMetrics: builtinMetrics,
-			Registry:       registry,
-		}, r1.MakeArchive())
-	require.NoError(t, err)
-	assert.NotNil(t, r2.GetDefaultGroup())
-}
-
 func TestRunnerOptions(t *testing.T) {
 	t.Parallel()
 	r1, err := getSimpleRunner(t, "/script.js", `exports.default = function() {};`)
@@ -398,8 +380,6 @@ func TestDataIsolation(t *testing.T) {
 	require.NoError(t, err)
 	defer stopOutputs(nil)
 
-	require.Empty(t, runner.defaultGroup.Groups)
-
 	stopEmission, err := execScheduler.Init(runCtx, samples)
 	require.NoError(t, err)
 
@@ -416,8 +396,6 @@ func TestDataIsolation(t *testing.T) {
 		require.NoError(t, err)
 		waitForMetricsFlushed()
 	}
-	require.Contains(t, runner.defaultGroup.Groups, "setup")
-	require.Contains(t, runner.defaultGroup.Groups, "teardown")
 	var count int
 	for _, s := range mockOutput.Samples {
 		if s.Metric.Name == "mycounter" {
@@ -672,7 +650,6 @@ func TestVURunContext(t *testing.T) {
 				assert.Equal(t, null.IntFrom(10), state.Options.VUs)
 				assert.Equal(t, null.BoolFrom(true), state.Options.Throw)
 				assert.NotNil(t, state.Logger)
-				assert.Equal(t, r.GetDefaultGroup(), state.Group)
 				assert.Equal(t, vu.Transport, state.Transport)
 			}))
 
@@ -774,74 +751,6 @@ func TestVURunInterruptDoesntPanic(t *testing.T) {
 	}
 }
 
-func TestVUIntegrationGroups(t *testing.T) {
-	t.Parallel()
-	r1, err := getSimpleRunner(t, "/script.js", `
-		var group = require("k6").group;
-		exports.default = function() {
-			fnOuter();
-			group("my group", function() {
-				fnInner();
-				group("nested group", function() {
-					fnNested();
-				})
-			});
-		}
-		`)
-	require.NoError(t, err)
-
-	registry := metrics.NewRegistry()
-	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
-	r2, err := NewFromArchive(
-		&lib.TestPreInitState{
-			Logger:         testutils.NewLogger(t),
-			BuiltinMetrics: builtinMetrics,
-			Registry:       registry,
-		}, r1.MakeArchive())
-	require.NoError(t, err)
-
-	testdata := map[string]*Runner{"Source": r1, "Archive": r2}
-	for name, r := range testdata {
-		r := r
-		t.Run(name, func(t *testing.T) {
-			t.Parallel()
-			ctx, cancel := context.WithCancel(context.Background())
-			defer cancel()
-
-			vu, err := r.newVU(ctx, 1, 1, make(chan metrics.SampleContainer, 100))
-			require.NoError(t, err)
-
-			fnOuterCalled := false
-			fnInnerCalled := false
-			fnNestedCalled := false
-			require.NoError(t, vu.Runtime.Set("fnOuter", func() {
-				fnOuterCalled = true
-				assert.Equal(t, r.GetDefaultGroup(), vu.state.Group)
-			}))
-			require.NoError(t, vu.Runtime.Set("fnInner", func() {
-				fnInnerCalled = true
-				g := vu.state.Group
-				assert.Equal(t, "my group", g.Name)
-				assert.Equal(t, r.GetDefaultGroup(), g.Parent)
-			}))
-			require.NoError(t, vu.Runtime.Set("fnNested", func() {
-				fnNestedCalled = true
-				g := vu.state.Group
-				assert.Equal(t, "nested group", g.Name)
-				assert.Equal(t, "my group", g.Parent.Name)
-				assert.Equal(t, r.GetDefaultGroup(), g.Parent.Parent)
-			}))
-
-			activeVU := vu.Activate(&lib.VUActivationParams{RunContext: ctx})
-			err = activeVU.RunOnce()
-			require.NoError(t, err)
-			assert.True(t, fnOuterCalled, "fnOuter() not called")
-			assert.True(t, fnInnerCalled, "fnInner() not called")
-			assert.True(t, fnNestedCalled, "fnNested() not called")
-		})
-	}
-}
-
 func TestVUIntegrationMetrics(t *testing.T) {
 	t.Parallel()
 	testdata := make(map[string]*Runner, 2)
@@ -2321,79 +2230,6 @@ func TestSystemTags(t *testing.T) {
 	}
 }
 
-func TestVUPanic(t *testing.T) {
-	t.Parallel()
-	r1, err := getSimpleRunner(t, "/script.js", `
-			var group = require("k6").group;
-			exports.default = function() {
-				group("panic here", function() {
-					if (__ITER == 0) {
-						panic("here we panic");
-					}
-					console.log("here we don't");
-				})
-			}`,
-	)
-	require.NoError(t, err)
-
-	registry := metrics.NewRegistry()
-	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
-	r2, err := NewFromArchive(
-		&lib.TestPreInitState{
-			Logger:         testutils.NewLogger(t),
-			BuiltinMetrics: builtinMetrics,
-			Registry:       registry,
-		}, r1.MakeArchive())
-	require.NoError(t, err)
-
-	runners := map[string]*Runner{"Source": r1, "Archive": r2}
-	for name, r := range runners {
-		r := r
-		t.Run(name, func(t *testing.T) {
-			t.Parallel()
-			ctx, cancel := context.WithCancel(context.Background())
-			defer cancel()
-
-			initVU, err := r.NewVU(ctx, 1, 1234, make(chan metrics.SampleContainer, 100))
-			require.NoError(t, err)
-
-			logger := logrus.New()
-			logger.SetLevel(logrus.InfoLevel)
-			logger.Out = io.Discard
-			hook := testutils.NewLogHook(
-				logrus.InfoLevel, logrus.ErrorLevel, logrus.FatalLevel, logrus.PanicLevel,
-			)
-			logger.AddHook(hook)
-
-			vu := initVU.Activate(&lib.VUActivationParams{RunContext: ctx})
-			activeVU, ok := vu.(*ActiveVU)
-			require.True(t, ok)
-			require.NoError(t, activeVU.Runtime.Set("panic", func(str string) { panic(str) }))
-			activeVU.state.Logger = logger
-
-			activeVU.Console.logger = logger.WithField("source", "console")
-			err = vu.RunOnce()
-			require.Error(t, err)
-			assert.Contains(t, err.Error(), "a panic occurred during JS execution: here we panic")
-			entries := hook.Drain()
-			require.Len(t, entries, 1)
-			assert.Equal(t, logrus.ErrorLevel, entries[0].Level)
-			require.True(t, strings.HasPrefix(entries[0].Message, "panic: here we panic"))
-			// broken since goja@f3cfc97811c0b4d8337902c3e42fb2371ba1d524 see
-			// https://github.com/dop251/goja/issues/179#issuecomment-783572020
-			// require.True(t, strings.HasSuffix(entries[0].Message, "Goja stack:\nfile:///script.js:3:4(12)"))
-
-			err = vu.RunOnce()
-			require.NoError(t, err)
-
-			entries = hook.Drain()
-			require.Len(t, entries, 1)
-			assert.Equal(t, logrus.InfoLevel, entries[0].Level)
-			require.Contains(t, entries[0].Message, "here we don't")
-		})
-	}
-}
-
 type multiFileTestCase struct {
 	fses       map[string]fsext.Fs
 	rtOpts     lib.RuntimeOptions
