@@ -17,6 +17,8 @@ const (
 	CompatibilityModeExtended CompatibilityMode = iota + 1
 	// CompatibilityModeBase is standard goja ES5.1+
 	CompatibilityModeBase
+	// CompatibilityModeExperimentalEnhanced achieves TypeScript and ES6+ compatibility with esbuild
+	CompatibilityModeExperimentalEnhanced
 )
 
 // RuntimeOptions are settings passed onto the goja JS runtime
